summaryrefslogtreecommitdiffstats
path: root/Source/cmMessageCommand.cxx
diff options
context:
space:
mode:
authorBrad King <brad.king@kitware.com>2016-06-13 13:54:27 (GMT)
committerCMake Topic Stage <kwrobot@kitware.com>2016-06-13 13:54:27 (GMT)
commit4e66ca1952c0ba9dfba6050f83f67c90884c8492 (patch)
treeba64a2020360c326489b43e422a1edf55489880b /Source/cmMessageCommand.cxx
parent18e00ac7b918865c38a2e34ee584e18c1126c663 (diff)
parent23f87e8157770c56d3aa568f3d1318f9b9070364 (diff)
downloadCMake-4e66ca1952c0ba9dfba6050f83f67c90884c8492.zip
CMake-4e66ca1952c0ba9dfba6050f83f67c90884c8492.tar.gz
CMake-4e66ca1952c0ba9dfba6050f83f67c90884c8492.tar.bz2
Merge topic 'fix-cmake-ISP-violation'
23f87e81 cmake: Remove force from IssueMessage API 54c65d5f cmake: Extract DisplayMessage API.
Diffstat (limited to 'Source/cmMessageCommand.cxx')
-rw-r--r--Source/cmMessageCommand.cxx5
1 files changed, 3 insertions, 2 deletions
diff --git a/Source/cmMessageCommand.cxx b/Source/cmMessageCommand.cxx
index dab90c9..080880b 100644
--- a/Source/cmMessageCommand.cxx
+++ b/Source/cmMessageCommand.cxx
@@ -64,8 +64,9 @@ bool cmMessageCommand::InitialPass(std::vector<std::string> const& args,
std::string message = cmJoin(cmMakeRange(i, args.end()), std::string());
if (type != cmake::MESSAGE) {
- // we've overriden the message type, above, so force IssueMessage to use it
- this->Makefile->IssueMessage(type, message, true);
+ // we've overriden the message type, above, so display it directly
+ cmake* cm = this->Makefile->GetCMakeInstance();
+ cm->DisplayMessage(type, message, this->Makefile->GetBacktrace());
} else {
if (status) {
this->Makefile->DisplayStatus(message.c_str(), -1);